WFC3 ImageObjects — drizzlepac 1.0.6 (14-Aug-2012) documentation

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »

# WFC3 ImageObjects

class `drizzlepac.wfc3Data.` `WFC3InputImage`(filename=None, group=None)

  Bases: `drizzlepac.imageObject.imageObject`

  `SEPARATOR` = '_'

class `drizzlepac.wfc3Data.` `WFC3UVISInputImage`(filename=None, group=None)

  Bases: `drizzlepac.wfc3Data.WFC3InputImage`

  `doUnitConversions`()
  `getdarkcurrent`(chip)

    Return the dark current for the WFC3 UVIS detector. This value will be contained within an instrument specific keyword.

    Returns :
    | darkcurrent: float : The dark current value with units of electrons.

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

class `drizzlepac.wfc3Data.` `WFC3IRInputImage`(filename=None, group=None)

  Bases: `drizzlepac.wfc3Data.WFC3InputImage`

  `doUnitConversions`()

    WF3 IR data come out in electrons, and I imagine the photometry keywords will be calculated as such, so no image manipulation needs be done between native and electrons

  `getdarkcurrent`()

    Return the dark current for the WFC3/IR detector. This value will be contained within an instrument specific keyword.

    Returns :
    | darkcurrent: float : The dark current value in units of electrons.

  `getdarkimg`(chip)

    Return an array representing the dark image for the detector.

    Returns :
    | dark: array : Dark image array in the same shape as the input image with units of cps

  `getexptimeimg`(chip)

    Return an array representing the exposure time per pixel for the detector.

    Returns :
    | dark: array : Exposure time array in the same shape as the input image

  `setInstrumentParameters`(instrpars)

    This method overrides the superclass to set default values into the parameter dictionary, in case empty entries are provided.

### Navigation

- index
- modules |
- next |
- previous |
- drizzlepac 1.0.6 (14-Aug-2012) documentation »
- imageObject Classes »